@@ -28,8 +28,8 @@ class EnumValue(Node):
 
         :param d: Node dictionary
         """
-        #self.__dict__.update(make_private(self, d))
-        for k,v in make_private(self, d).items():
+
+        for k,v in self.make_private(self, d).items():
             self.__setattr__(k,v)
 
     @property
