@@ -93,7 +93,7 @@ def signal_endianess(signal):
 
     if signal.byte_order not in endianess:
         return fail_msg(
-            signal, f"signal endianess not supported. Valid values are: {endianess}"
+            signal, f"signal endianess not supported. Valid values are: {endianess} got {signal.byte_order}"
         )
 
 
@@ -137,7 +137,7 @@ def msg_mux(msg):
 
     mux = msg.signals.get(muxeds[0])
     if mux == None:
-        return fail_msg(msg, f"Cannot find mux signal in multiplexed message")
+        return fail_msg(msg, f"Cannot find mux signal in multiplexed message got {muxeds[0]}")
 
     if 2 ** mux.length < mux.mux_count:
         return fail_msg(msg, f"Mux cannot fit all possible multiplexed values")
@@ -257,12 +257,11 @@ def spec_overlapping_dev_ids(spec):
         return fail_msg(spec, f"There are overlapping device ids")
 
 
-@check_decorator("spec")
-def spec_same_name_configs(spec):
+@check_decorator("dev")
+def spec_same_name_configs(device):
     cfgs = []
-    for dev in spec.devices.values():
-        for cfg in dev.cfgs.values():
-            cfgs += [cfg.name]
+    for cfg in device.cfgs.values():
+        cfgs += [cfg.name]
 
     cfgs_set = set()
 
@@ -278,12 +277,11 @@ def spec_same_name_configs(spec):
         )
 
 
-@check_decorator("spec")
-def spec_same_name_commands(spec):
+@check_decorator("dev")
+def spec_same_name_commands(dev):
     cmds = []
-    for dev in spec.devices.values():
-        for cmd in dev.cmds.values():
-            cmds += [cmd.name]
+    for cmd in dev.cmds.values():
+        cmds += [cmd.name]
 
     cmds_set = set()
 
